Index: FOIAVistA/tag/r/IMAGING-MAG-ZMAG/MAGGTU3.m
===================================================================
--- FOIAVistA/trunk/r/IMAGING-MAG-ZMAG/MAGGTU3.m	(revision 631)
+++ FOIAVistA/tag/r/IMAGING-MAG-ZMAG/MAGGTU3.m	(revision 636)
@@ -1,5 +1,5 @@
 MAGGTU3 ;WOIFO/GEK - Silent calls for Imaging ; [ 06/20/2001 08:57 ]
- ;;3.0;IMAGING;**7,8,48,45,20,46,59**;Nov 27, 2007;Build 20
- ;;Per VHA Directive 2004-038, this routine should not be modified.
+ ;;3.0;IMAGING;**7,8,48,45,20,46**;16-February-2007;;Build 1023
+ ;; Per VHA Directive 2004-038, this routine should not be modified.
  ;; +---------------------------------------------------------------+
  ;; | Property of the US Government.                                |
@@ -18,6 +18,6 @@
  Q
 IMAGEINF(MAGRY,IEN,NOCHK) ;RPC [MAGG IMAGE INFO] Call to return information for 1 image;
- ; IEN   =       Image IEN  ^MAG(2005,IEN
- ; NOCHK =    1|""   if 1 then do not run QA check on this image.
+ ; IEN   =       Image IEN ^MAG(2005,IEN
+ ; NOCHK =   If Flag = 1, then do not run QA check on this image.
  ; 
  N MAGFILE,Y,Z,MAGNOCHK
@@ -66,10 +66,10 @@
  ; NOW NET STUFF
  I 'MAGPLC Q 
- ; From IMAGING SITE PARAMETERS File
- ;   get the Network UserName and PassWord.
+ ; Get info from IMAGING SITE PARAMETERS File
+ ; get the Network UserName and PassWord.
  S MAGRY(2)=$P($G(^MAG(2006.1,MAGPLC,"NET")),U,1,2)
- ;   get the default MUSE Site number.
+ ; get the default MUSE Site number.
  S MAGRY(3)=+$P($G(^MAG(2006.1,MAGPLC,"USERPREF")),U,2)
- ;   default to 1 if nothing is entered in Site Parameters File
+ ; default to 1 if nothing is entered in Site Parameters File
  I MAGRY(3)=0 S MAGRY(3)=1
  ; This SITEIEN^SITECODE^USER INSTITUTION IEN^INSTITUTION NAME^CONSOLIDATED^User's local STATION NUMBER
@@ -80,6 +80,6 @@
  S MAGJOB("PLCODE")=$$GET1^DIQ(2006.1,MAGPLC,.09)
  S MAGRY(4)=MAGRY(4)_U_$$CONSOLID^MAGBAPI_U_$$GET1^DIQ(4,DUZ(2),99,"E")
  ; is CP not installed at this site, the Client will hide options
  ;  related to CP.
  S X=$$VERSION^XPDUTL("CLINICAL PROCEDURES")
  S MAGRY(5)=+X_U_X
@@ -158,6 +158,63 @@
  Q
 GETINFO(MAGRY,IEN) ; RPC [MAG4 GET IMAGE INFO]
- ; Call (3.0p8) to get information on 1 image 
- ; and Display in the Image Information Window
- D GETINFO^MAGGTU31(.MAGRY,IEN)
- Q
+ ; Call (3.0p8) to get information on 1 image
+ N Y,J,JI,I,CT,IENC,FLAGS,SNGRP,Z,M40,T,QACHK
+ S I=0,CT=0
+ S MAGRY(CT)="Image ID#:      "_IEN
+ I $D(^MAG(2005.1,IEN)) D  Q
+ . S CT=CT+1,MAGRY(CT)="    STATUS:  "_"HAS BEEN DELETED. !!"
+ . S CT=CT+1,MAGRY(CT)="Deleted By: "_$$GET1^DIQ(2005.1,IEN,30,"E")
+ . S CT=CT+1,MAGRY(CT)="    Reason: "_$$GET1^DIQ(2005.1,IEN,30.2,"E")
+ . S CT=CT+1,MAGRY(CT)="      Date: "_$$GET1^DIQ(2005.1,IEN,30.1,"E")
+ . Q
+ S M40=$G(^MAG(2005,IEN,40)),T=$P(M40,"^",3)
+ S Z=$P($G(^MAG(2005,IEN,0)),"^",10) I Z D
+ . S CT=CT+1,MAGRY(CT)=" is in Group#: "_Z_"  ("_+$P(^MAG(2005,Z,1,0),"^",4)_" images)"
+ . D CHK^MAGGSQI(.QACHK,Z) Q:QACHK(0) 
+ . S CT=CT+1,MAGRY(CT)=" QA Warning - Group#: "_Z_" "_$P(QACHK(0),"^",2)
+ . Q
+ S SNGRP="FLDS"
+ I (+$O(^MAG(2005,IEN,1,0)))!($P(^MAG(2005,IEN,0),"^",6)=11)!($P(^MAG(2005,IEN,0),"^",6)=16) D
+ . S CT=CT+1,MAGRY(CT)=$P(^MAG(2005,IEN,0),"^",8)_" Group of "_+$P($G(^MAG(2005,IEN,1,0)),U,4)
+ . S SNGRP="FLDG"
+ . Q
+ K QACHK
+ D CHK^MAGGSQI(.QACHK,IEN) I 'QACHK(0) D
+ . S CT=CT+1,MAGRY(CT)=" QA Warning - Image#: "_IEN_" "_$P(QACHK(0),"^",2)
+ N MAGOUT,MAGERR,MAGVAL
+ S IENC=IEN_","
+ S FLAGS="EN"
+ S I=-1
+ F  S I=I+1,Z=$T(@SNGRP+I) Q:$P(Z,";",3)="end"  D
+ . S J=$P(Z,";",4),JI=J_";"
+ . K MAGOUT
+ . S CT=CT+1,MAGRY(CT)=$P(Z,";",3)
+ . I J=41 D  Q  ; Need to compute the Class.  Class field in Image File is wrong.
+ . . S MAGVAL=$S('T:"",'$D(^MAG(2005.83,T,0)):"",1:$P(^MAG(2005.82,$P(^MAG(2005.83,T,0),"^",2),0),"^",1))
+ . . S MAGRY(CT)=MAGRY(CT)_" "_MAGVAL
+ . . Q
+ . D GETS^DIQ(2005,IEN,JI,FLAGS,"MAGOUT","MAGERR")
+ . ; Get Extension from FileRef
+ . I J=1 S MAGVAL=$P($G(MAGOUT(2005,IENC,J,"E")),".",2)
+ . E  S MAGVAL=$G(MAGOUT(2005,IENC,J,"E"))
+ . S MAGRY(CT)=MAGRY(CT)_" "_MAGVAL
+ ; Compare Parent Association Date with Date/Time Note Signed.
+ I $P(^MAG(2005,IEN,0),"^",10) S IEN=$P(^MAG(2005,IEN,0),"^",10)
+ I $P(^MAG(2005,IEN,2),"^",6)=8925 S CT=CT+1,MAGRY(CT)=$$ATTSTAT^MAGGTU31(IEN)
+ Q
+ ;
+FLDS ;;Format:       ;3;;
+ ;;Extension:    ;1;;
+FLDG ;;Patient:      ;5;;
+ ;;Desc:         ;10;;
+ ;;Procedure:    ;6;;
+ ;;     Date:    ;15;;
+ ;;Class:        ;41;;
+ ;;Package:      ;40;;
+ ;;Type:         ;42;;
+ ;;Proc/Event:   ;43;;
+ ;;Spec/SubSpec: ;44;;
+ ;;Origin:       ;45;;
+ ;;Captured on:  ;7;;
+ ;;         by:  ;8;;
+ ;;end;;
@@ -80,6 +80,6 @@
  S MAGJOB("PLCODE")=$$GET1^DIQ(2006.1,MAGPLC,.09)
  S MAGRY(4)=MAGRY(4)_U_$$CONSOLID^MAGBAPI_U_$$GET1^DIQ(4,DUZ(2),99,"E")
- ; is CP not installed at this site, the Client will hide options
- ;  related to CP.
+ ; is CP installed at this site, the Front End will hide options
+ ;  related to CP if not installed.
  S X=$$VERSION^XPDUTL("CLINICAL PROCEDURES")
  S MAGRY(5)=+X_U_X
